/* FSpotPhotoVersionsTable.c generated by valac 0.36.6, the Vala compiler
 * generated from FSpotPhotoVersionsTable.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <sqlite3.h>
#include <gee.h>


#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW (data_imports_fspot_db_fspot_photo_version_row_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSION_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW, DataImportsFSpotDbFSpotPhotoVersionRow))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSION_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW, DataImportsFSpotDbFSpotPhotoVersionRowClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSION_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSION_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSION_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW, DataImportsFSpotDbFSpotPhotoVersionRowClass))

typedef struct _DataImportsFSpotDbFSpotPhotoVersionRow DataImportsFSpotDbFSpotPhotoVersionRow;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionRowClass DataImportsFSpotDbFSpotPhotoVersionRowClass;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionRowPrivate DataImportsFSpotDbFSpotPhotoVersionRowPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_IMPORTABLE_DATABASE_TABLE (importable_database_table_get_type ())
#define IMPORTABLE_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORTABLE_DATABASE_TABLE, ImportableDatabaseTable))
#define IMPORTABLE_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORTABLE_DATABASE_TABLE, ImportableDatabaseTableClass))
#define IS_IMPORTABLE_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORTABLE_DATABASE_TABLE))
#define IS_IMPORTABLE_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORTABLE_DATABASE_TABLE))
#define IMPORTABLE_DATABASE_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORTABLE_DATABASE_TABLE, ImportableDatabaseTableClass))

typedef struct _ImportableDatabaseTable ImportableDatabaseTable;
typedef struct _ImportableDatabaseTableClass ImportableDatabaseTableClass;
typedef struct _ImportableDatabaseTablePrivate ImportableDatabaseTablePrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE (data_imports_fspot_db_fspot_database_table_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTableClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTableClass))

typedef struct _DataImportsFSpotDbFSpotDatabaseTable DataImportsFSpotDbFSpotDatabaseTable;
typedef struct _DataImportsFSpotDbFSpotDatabaseTableClass DataImportsFSpotDbFSpotDatabaseTableClass;
typedef struct _DataImportsFSpotDbFSpotDatabaseTablePrivate DataImportsFSpotDbFSpotDatabaseTablePrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR (data_imports_fspot_db_fspot_table_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TABLE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_TABLE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TABLE_BEHAVIOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehaviorIface))

typedef struct _DataImportsFSpotDbFSpotTableBehavior DataImportsFSpotDbFSpotTableBehavior;
typedef struct _DataImportsFSpotDbFSpotTableBehaviorIface DataImportsFSpotDbFSpotTableBehaviorIface;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_TABLE (data_imports_fspot_db_fspot_photo_versions_table_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_TABLE, DataImportsFSpotDbFSpotPhotoVersionsTable))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_TABLE, DataImportsFSpotDbFSpotPhotoVersionsTableClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_TABLE))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_TABLE))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_TABLE, DataImportsFSpotDbFSpotPhotoVersionsTableClass))

typedef struct _DataImportsFSpotDbFSpotPhotoVersionsTable DataImportsFSpotDbFSpotPhotoVersionsTable;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsTableClass DataImportsFSpotDbFSpotPhotoVersionsTableClass;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsTablePrivate DataImportsFSpotDbFSpotPhotoVersionsTablePrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR (data_imports_fspot_db_fspot_database_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR, DataImportsFSpotDbFSpotDatabaseBehavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR, DataImportsFSpotDbFSpotDatabaseBehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR, DataImportsFSpotDbFSpotDatabaseBehaviorClass))

typedef struct _DataImportsFSpotDbFSpotDatabaseBehavior DataImportsFSpotDbFSpotDatabaseBehavior;
typedef struct _DataImportsFSpotDbFSpotDatabaseBehaviorClass DataImportsFSpotDbFSpotDatabaseBehaviorClass;
#define _sqlite3_finalize0(var) ((var == NULL) ? NULL : (var = (sqlite3_finalize (var), NULL)))

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR (data_imports_fspot_db_fspot_photo_versions_v0_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV0Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV0Behavior DataImportsFSpotDbFSpotPhotoVersionsV0Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorClass DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorClass;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorPrivate DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorPrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR (data_imports_fspot_db_fspot_photo_versions_v9_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV9Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV9Behavior DataImportsFSpotDbFSpotPhotoVersionsV9Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorClass DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorClass;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorPrivate DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorPrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR (data_imports_fspot_db_fspot_photo_versions_v16_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV16Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV16Behavior DataImportsFSpotDbFSpotPhotoVersionsV16Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorClass DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorClass;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorPrivate DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorPrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR (data_imports_fspot_db_fspot_photo_versions_v17_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV17Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV17Behavior DataImportsFSpotDbFSpotPhotoVersionsV17Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorClass DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorClass;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorPrivate DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorPrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR (data_imports_fspot_db_fspot_photo_versions_v18_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV18Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV18Behavior DataImportsFSpotDbFSpotPhotoVersionsV18Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorClass DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorClass;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorPrivate DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorPrivate;

struct _DataImportsFSpotDbFSpotPhotoVersionRow {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotoVersionRowPrivate * priv;
	gint64 photo_id;
	gint64 version_id;
	gchar* name;
	GFile* base_path;
	gchar* filename;
	gchar* md5_sum;
	gboolean is_protected;
};

struct _DataImportsFSpotDbFSpotPhotoVersionRowClass {
	GObjectClass parent_class;
};

struct _ImportableDatabaseTable {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportableDatabaseTablePrivate * priv;
	gchar* table_name;
};

struct _ImportableDatabaseTableClass {
	GTypeClass parent_class;
	void (*finalize) (ImportableDatabaseTable *self);
};

struct _DataImportsFSpotDbFSpotTableBehaviorIface {
	GTypeInterface parent_iface;
	gchar* (*get_table_name) (DataImportsFSpotDbFSpotTableBehavior* self);
	gchar** (*list_columns) (DataImportsFSpotDbFSpotTableBehavior* self, int* result_length1);
	void (*build_row) (DataImportsFSpotDbFSpotTableBehavior* self, sqlite3_stmt* stmt, gpointer* row, gint offset);
};

struct _DataImportsFSpotDbFSpotDatabaseTable {
	ImportableDatabaseTable parent_instance;
	DataImportsFSpotDbFSpotDatabaseTablePrivate * priv;
	sqlite3* fspot_db;
	DataImportsFSpotDbFSpotTableBehavior* behavior;
};

struct _DataImportsFSpotDbFSpotDatabaseTableClass {
	ImportableDatabaseTableClass parent_class;
};

struct _DataImportsFSpotDbFSpotPhotoVersionsTable {
	DataImportsFSpotDbFSpotDatabaseTable parent_instance;
	DataImportsFSpotDbFSpotPhotoVersionsTablePrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotoVersionsTableClass {
	DataImportsFSpotDbFSpotDatabaseTableClass parent_class;
};

typedef enum  {
	DATABASE_ERROR_ERROR,
	DATABASE_ERROR_BACKING,
	DATABASE_ERROR_MEMORY,
	DATABASE_ERROR_ABORT,
	DATABASE_ERROR_LIMITS,
	DATABASE_ERROR_TYPESPEC
} DatabaseError;
#define DATABASE_ERROR database_error_quark ()
struct _DataImportsFSpotDbFSpotPhotoVersionsV0Behavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorClass {
	GObjectClass parent_class;
};

struct _DataImportsFSpotDbFSpotPhotoVersionsV9Behavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorClass {
	GObjectClass parent_class;
};

struct _DataImportsFSpotDbFSpotPhotoVersionsV16Behavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorClass {
	GObjectClass parent_class;
};

struct _DataImportsFSpotDbFSpotPhotoVersionsV17Behavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorClass {
	GObjectClass parent_class;
};

struct _DataImportsFSpotDbFSpotPhotoVersionsV18Behavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorClass {
	GObjectClass parent_class;
};


static gpointer data_imports_fspot_db_fspot_photo_version_row_parent_class = NULL;
static gpointer data_imports_fspot_db_fspot_photo_versions_table_parent_class = NULL;
static gpointer data_imports_fspot_db_fspot_photo_versions_v0_behavior_parent_class = NULL;
static DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* data_imports_fspot_db_fspot_photo_versions_v0_behavior_instance;
static DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* data_imports_fspot_db_fspot_photo_versions_v0_behavior_instance = NULL;
static DataImportsFSpotDbFSpotTableBehaviorIface * data_imports_fspot_db_fspot_photo_versions_v0_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = NULL;
static gpointer data_imports_fspot_db_fspot_photo_versions_v9_behavior_parent_class = NULL;
static DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* data_imports_fspot_db_fspot_photo_versions_v9_behavior_instance;
static DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* data_imports_fspot_db_fspot_photo_versions_v9_behavior_instance = NULL;
static DataImportsFSpotDbFSpotTableBehaviorIface * data_imports_fspot_db_fspot_photo_versions_v9_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = NULL;
static gpointer data_imports_fspot_db_fspot_photo_versions_v16_behavior_parent_class = NULL;
static DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* data_imports_fspot_db_fspot_photo_versions_v16_behavior_instance;
static DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* data_imports_fspot_db_fspot_photo_versions_v16_behavior_instance = NULL;
static DataImportsFSpotDbFSpotTableBehaviorIface * data_imports_fspot_db_fspot_photo_versions_v16_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = NULL;
static gpointer data_imports_fspot_db_fspot_photo_versions_v17_behavior_parent_class = NULL;
static DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* data_imports_fspot_db_fspot_photo_versions_v17_behavior_instance;
static DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* data_imports_fspot_db_fspot_photo_versions_v17_behavior_instance = NULL;
static DataImportsFSpotDbFSpotTableBehaviorIface * data_imports_fspot_db_fspot_photo_versions_v17_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = NULL;
static gpointer data_imports_fspot_db_fspot_photo_versions_v18_behavior_parent_class = NULL;
static DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* data_imports_fspot_db_fspot_photo_versions_v18_behavior_instance;
static DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* data_imports_fspot_db_fspot_photo_versions_v18_behavior_instance = NULL;
static DataImportsFSpotDbFSpotTableBehaviorIface * data_imports_fspot_db_fspot_photo_versions_v18_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = NULL;

GType data_imports_fspot_db_fspot_photo_version_row_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSION_ROW_DUMMY_PROPERTY
};
DataImportsFSpotDbFSpotPhotoVersionRow* data_imports_fspot_db_fspot_photo_version_row_new (void);
DataImportsFSpotDbFSpotPhotoVersionRow* data_imports_fspot_db_fspot_photo_version_row_construct (GType object_type);
static void data_imports_fspot_db_fspot_photo_version_row_finalize (GObject * obj);
gpointer importable_database_table_ref (gpointer instance);
void importable_database_table_unref (gpointer instance);
GParamSpec* param_spec_importable_database_table (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_importable_database_table (GValue* value, gpointer v_object);
void value_take_importable_database_table (GValue* value, gpointer v_object);
gpointer value_get_importable_database_table (const GValue* value);
GType importable_database_table_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_database_table_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_table_behavior_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_photo_versions_table_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_TABLE_DUMMY_PROPERTY
};
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_TABLE_TABLE_NAME "Photo_versions"
GType data_imports_fspot_db_fspot_database_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotoVersionsTable* data_imports_fspot_db_fspot_photo_versions_table_new (sqlite3* db, DataImportsFSpotDbFSpotDatabaseBehavior* db_behavior);
DataImportsFSpotDbFSpotPhotoVersionsTable* data_imports_fspot_db_fspot_photo_versions_table_construct (GType object_type, sqlite3* db, DataImportsFSpotDbFSpotDatabaseBehavior* db_behavior);
DataImportsFSpotDbFSpotDatabaseTable* data_imports_fspot_db_fspot_database_table_construct (GType object_type, GType t_type, GBoxedCopyFunc t_dup_func, GDestroyNotify t_destroy_func, sqlite3* db);
void data_imports_fspot_db_fspot_database_table_set_behavior (DataImportsFSpotDbFSpotDatabaseTable* self, DataImportsFSpotDbFSpotTableBehavior* behavior);
DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_get_photo_versions_behavior (DataImportsFSpotDbFSpotDatabaseBehavior* self);
GQuark database_error_quark (void);
GeeArrayList* data_imports_fspot_db_fspot_photo_versions_table_get_by_photo_id (DataImportsFSpotDbFSpotPhotoVersionsTable* self, gint64 photo_id, GError** error);
gchar* data_imports_fspot_db_fspot_database_table_get_joined_column_list (DataImportsFSpotDbFSpotDatabaseTable* self, gboolean with_table);
void importable_database_table_throw_error (const gchar* method, gint res, GError** error);
void data_imports_fspot_db_fspot_table_behavior_build_row (DataImportsFSpotDbFSpotTableBehavior* self, sqlite3_stmt* stmt, gpointer* row, gint offset);
GType data_imports_fspot_db_fspot_photo_versions_v0_behavior_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR_DUMMY_PROPERTY
};
static DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* data_imports_fspot_db_fspot_photo_versions_v0_behavior_new (void);
static DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* data_imports_fspot_db_fspot_photo_versions_v0_behavior_construct (GType object_type);
DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* data_imports_fspot_db_fspot_photo_versions_v0_behavior_get_instance (void);
static gchar* data_imports_fspot_db_fspot_photo_versions_v0_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base);
static gchar** data_imports_fspot_db_fspot_photo_versions_v0_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1);
static void data_imports_fspot_db_fspot_photo_versions_v0_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoVersionRow* * row, gint offset);
static void data_imports_fspot_db_fspot_photo_versions_v0_behavior_finalize (GObject * obj);
GType data_imports_fspot_db_fspot_photo_versions_v9_behavior_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR_DUMMY_PROPERTY
};
static DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* data_imports_fspot_db_fspot_photo_versions_v9_behavior_new (void);
static DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* data_imports_fspot_db_fspot_photo_versions_v9_behavior_construct (GType object_type);
DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* data_imports_fspot_db_fspot_photo_versions_v9_behavior_get_instance (void);
static gchar* data_imports_fspot_db_fspot_photo_versions_v9_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base);
static gchar** data_imports_fspot_db_fspot_photo_versions_v9_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1);
static void data_imports_fspot_db_fspot_photo_versions_v9_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoVersionRow* * row, gint offset);
static void data_imports_fspot_db_fspot_photo_versions_v9_behavior_finalize (GObject * obj);
GType data_imports_fspot_db_fspot_photo_versions_v16_behavior_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR_DUMMY_PROPERTY
};
static DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* data_imports_fspot_db_fspot_photo_versions_v16_behavior_new (void);
static DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* data_imports_fspot_db_fspot_photo_versions_v16_behavior_construct (GType object_type);
DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* data_imports_fspot_db_fspot_photo_versions_v16_behavior_get_instance (void);
static gchar* data_imports_fspot_db_fspot_photo_versions_v16_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base);
static gchar** data_imports_fspot_db_fspot_photo_versions_v16_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1);
static void data_imports_fspot_db_fspot_photo_versions_v16_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoVersionRow* * row, gint offset);
static void data_imports_fspot_db_fspot_photo_versions_v16_behavior_finalize (GObject * obj);
GType data_imports_fspot_db_fspot_photo_versions_v17_behavior_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR_DUMMY_PROPERTY
};
static DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* data_imports_fspot_db_fspot_photo_versions_v17_behavior_new (void);
static DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* data_imports_fspot_db_fspot_photo_versions_v17_behavior_construct (GType object_type);
DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* data_imports_fspot_db_fspot_photo_versions_v17_behavior_get_instance (void);
static gchar* data_imports_fspot_db_fspot_photo_versions_v17_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base);
static gchar** data_imports_fspot_db_fspot_photo_versions_v17_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1);
static void data_imports_fspot_db_fspot_photo_versions_v17_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoVersionRow* * row, gint offset);
static void data_imports_fspot_db_fspot_photo_versions_v17_behavior_finalize (GObject * obj);
GType data_imports_fspot_db_fspot_photo_versions_v18_behavior_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR_DUMMY_PROPERTY
};
static DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* data_imports_fspot_db_fspot_photo_versions_v18_behavior_new (void);
static DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* data_imports_fspot_db_fspot_photo_versions_v18_behavior_construct (GType object_type);
DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* data_imports_fspot_db_fspot_photo_versions_v18_behavior_get_instance (void);
static gchar* data_imports_fspot_db_fspot_photo_versions_v18_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base);
static gchar** data_imports_fspot_db_fspot_photo_versions_v18_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1);
static void data_imports_fspot_db_fspot_photo_versions_v18_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoVersionRow* * row, gint offset);
static void data_imports_fspot_db_fspot_photo_versions_v18_behavior_finalize (GObject * obj);


DataImportsFSpotDbFSpotPhotoVersionRow* data_imports_fspot_db_fspot_photo_version_row_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotoVersionRow * self = NULL;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = (DataImportsFSpotDbFSpotPhotoVersionRow*) g_object_new (object_type, NULL);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return self;
#line 368 "FSpotPhotoVersionsTable.c"
}


DataImportsFSpotDbFSpotPhotoVersionRow* data_imports_fspot_db_fspot_photo_version_row_new (void) {
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return data_imports_fspot_db_fspot_photo_version_row_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW);
#line 375 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_version_row_class_init (DataImportsFSpotDbFSpotPhotoVersionRowClass * klass) {
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	data_imports_fspot_db_fspot_photo_version_row_parent_class = g_type_class_peek_parent (klass);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photo_version_row_finalize;
#line 384 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_version_row_instance_init (DataImportsFSpotDbFSpotPhotoVersionRow * self) {
}


static void data_imports_fspot_db_fspot_photo_version_row_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotoVersionRow * self;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW, DataImportsFSpotDbFSpotPhotoVersionRow);
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (self->name);
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_object_unref0 (self->base_path);
#line 17 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (self->filename);
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (self->md5_sum);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photo_version_row_parent_class)->finalize (obj);
#line 406 "FSpotPhotoVersionsTable.c"
}


/**
 * The value object for the "photo_versions" table, representing a single database row.
 */
GType data_imports_fspot_db_fspot_photo_version_row_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photo_version_row_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photo_version_row_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotoVersionRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photo_version_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotoVersionRow), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photo_version_row_instance_init, NULL };
		GType data_imports_fspot_db_fspot_photo_version_row_type_id;
		data_imports_fspot_db_fspot_photo_version_row_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotoVersionRow", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_fspot_db_fspot_photo_version_row_type_id__volatile, data_imports_fspot_db_fspot_photo_version_row_type_id);
	}
	return data_imports_fspot_db_fspot_photo_version_row_type_id__volatile;
}


DataImportsFSpotDbFSpotPhotoVersionsTable* data_imports_fspot_db_fspot_photo_versions_table_construct (GType object_type, sqlite3* db, DataImportsFSpotDbFSpotDatabaseBehavior* db_behavior) {
	DataImportsFSpotDbFSpotPhotoVersionsTable* self = NULL;
	sqlite3* _tmp0_;
	DataImportsFSpotDbFSpotDatabaseBehavior* _tmp1_;
	DataImportsFSpotDbFSpotTableBehavior* _tmp2_;
	DataImportsFSpotDbFSpotTableBehavior* _tmp3_;
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	g_return_val_if_fail (db != NULL, NULL);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_BEHAVIOR (db_behavior), NULL);
#line 29 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = db;
#line 29 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = (DataImportsFSpotDbFSpotPhotoVersionsTable*) data_imports_fspot_db_fspot_database_table_construct (object_type, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp0_);
#line 30 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_ = db_behavior;
#line 30 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_database_behavior_get_photo_versions_behavior (_tmp1_);
#line 30 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = _tmp2_;
#line 30 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	data_imports_fspot_db_fspot_database_table_set_behavior (G_TYPE_CHECK_INSTANCE_CAST (self, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable), _tmp3_);
#line 30 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_object_unref0 (_tmp3_);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return self;
#line 451 "FSpotPhotoVersionsTable.c"
}


DataImportsFSpotDbFSpotPhotoVersionsTable* data_imports_fspot_db_fspot_photo_versions_table_new (sqlite3* db, DataImportsFSpotDbFSpotDatabaseBehavior* db_behavior) {
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return data_imports_fspot_db_fspot_photo_versions_table_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_TABLE, db, db_behavior);
#line 458 "FSpotPhotoVersionsTable.c"
}


GeeArrayList* data_imports_fspot_db_fspot_photo_versions_table_get_by_photo_id (DataImportsFSpotDbFSpotPhotoVersionsTable* self, gint64 photo_id, GError** error) {
	GeeArrayList* result = NULL;
	GeeArrayList* rows = NULL;
	GeeArrayList* _tmp0_;
	sqlite3_stmt* stmt = NULL;
	gchar* column_list = NULL;
	gchar* _tmp1_;
	gchar* sql = NULL;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gint res = 0;
	sqlite3* _tmp5_;
	const gchar* _tmp6_;
	sqlite3_stmt* _tmp7_ = NULL;
	gint _tmp8_;
	gint _tmp9_;
	sqlite3_stmt* _tmp14_;
	gint64 _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	sqlite3_stmt* _tmp19_;
	gint _tmp20_;
	GError * _inner_error_ = NULL;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_TABLE (self), NULL);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = gee_array_list_new (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	rows = _tmp0_;
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_ = data_imports_fspot_db_fspot_database_table_get_joined_column_list (G_TYPE_CHECK_INSTANCE_CAST (self, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable), FALSE);
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	column_list = _tmp1_;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = column_list;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORTABLE_DATABASE_TABLE, ImportableDatabaseTable)->table_name;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_ = g_strdup_printf ("SELECT %s FROM %s WHERE photo_id=?", _tmp2_, _tmp3_);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	sql = _tmp4_;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_ = G_TYPE_CHECK_INSTANCE_CAST (self, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable)->fspot_db;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_ = sql;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp8_ = sqlite3_prepare_v2 (_tmp5_, _tmp6_, -1, &_tmp7_, NULL);
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_sqlite3_finalize0 (stmt);
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	stmt = _tmp7_;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	res = _tmp8_;
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp9_ = res;
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp9_ != SQLITE_OK) {
#line 520 "FSpotPhotoVersionsTable.c"
		const gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gint _tmp13_;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp10_ = sql;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp11_ = g_strdup_printf ("Statement failed: %s", _tmp10_);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp12_ = _tmp11_;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp13_ = res;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		importable_database_table_throw_error (_tmp12_, _tmp13_, &_inner_error_);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_free0 (_tmp12_);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				g_propagate_error (error, _inner_error_);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_g_free0 (sql);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_g_free0 (column_list);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_sqlite3_finalize0 (stmt);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_g_object_unref0 (rows);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				return NULL;
#line 553 "FSpotPhotoVersionsTable.c"
			} else {
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_g_free0 (sql);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_g_free0 (column_list);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_sqlite3_finalize0 (stmt);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_g_object_unref0 (rows);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				g_clear_error (&_inner_error_);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				return NULL;
#line 569 "FSpotPhotoVersionsTable.c"
			}
		}
	}
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp14_ = stmt;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp15_ = photo_id;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp16_ = sqlite3_bind_int64 (_tmp14_, 1, _tmp15_);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	res = _tmp16_;
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp17_ = res;
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp17_ != SQLITE_OK) {
#line 585 "FSpotPhotoVersionsTable.c"
		gint _tmp18_;
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp18_ = res;
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		importable_database_table_throw_error ("Bind failed for photo_id", _tmp18_, &_inner_error_);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				g_propagate_error (error, _inner_error_);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_g_free0 (sql);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_g_free0 (column_list);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_sqlite3_finalize0 (stmt);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_g_object_unref0 (rows);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				return NULL;
#line 607 "FSpotPhotoVersionsTable.c"
			} else {
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_g_free0 (sql);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_g_free0 (column_list);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_sqlite3_finalize0 (stmt);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				_g_object_unref0 (rows);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				g_clear_error (&_inner_error_);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
				return NULL;
#line 623 "FSpotPhotoVersionsTable.c"
			}
		}
	}
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp19_ = stmt;
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp20_ = sqlite3_step (_tmp19_);
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	res = _tmp20_;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	while (TRUE) {
#line 635 "FSpotPhotoVersionsTable.c"
		gint _tmp21_;
		DataImportsFSpotDbFSpotPhotoVersionRow* row = NULL;
		DataImportsFSpotDbFSpotTableBehavior* _tmp22_;
		sqlite3_stmt* _tmp23_;
		gpointer _tmp24_ = NULL;
		GeeArrayList* _tmp25_;
		DataImportsFSpotDbFSpotPhotoVersionRow* _tmp26_;
		sqlite3_stmt* _tmp27_;
		gint _tmp28_;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp21_ = res;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		if (!(_tmp21_ == SQLITE_ROW)) {
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
			break;
#line 651 "FSpotPhotoVersionsTable.c"
		}
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp22_ = G_TYPE_CHECK_INSTANCE_CAST (self, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable)->behavior;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp23_ = stmt;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		data_imports_fspot_db_fspot_table_behavior_build_row (_tmp22_, _tmp23_, &_tmp24_, 0);
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (row);
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		row = _tmp24_;
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp25_ = rows;
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp26_ = row;
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp26_);
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp27_ = stmt;
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp28_ = sqlite3_step (_tmp27_);
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		res = _tmp28_;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (row);
#line 677 "FSpotPhotoVersionsTable.c"
	}
#line 59 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = rows;
#line 59 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (sql);
#line 59 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (column_list);
#line 59 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_sqlite3_finalize0 (stmt);
#line 59 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 689 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_table_class_init (DataImportsFSpotDbFSpotPhotoVersionsTableClass * klass) {
#line 25 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	data_imports_fspot_db_fspot_photo_versions_table_parent_class = g_type_class_peek_parent (klass);
#line 696 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_table_instance_init (DataImportsFSpotDbFSpotPhotoVersionsTable * self) {
}


/**
 * This class represents the F-Spot photo_versions table.
 */
GType data_imports_fspot_db_fspot_photo_versions_table_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photo_versions_table_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photo_versions_table_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotoVersionsTableClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photo_versions_table_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotoVersionsTable), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photo_versions_table_instance_init, NULL };
		GType data_imports_fspot_db_fspot_photo_versions_table_type_id;
		data_imports_fspot_db_fspot_photo_versions_table_type_id = g_type_register_static (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, "DataImportsFSpotDbFSpotPhotoVersionsTable", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_fspot_db_fspot_photo_versions_table_type_id__volatile, data_imports_fspot_db_fspot_photo_versions_table_type_id);
	}
	return data_imports_fspot_db_fspot_photo_versions_table_type_id__volatile;
}


static DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* data_imports_fspot_db_fspot_photo_versions_v0_behavior_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotoVersionsV0Behavior * self = NULL;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = (DataImportsFSpotDbFSpotPhotoVersionsV0Behavior*) g_object_new (object_type, NULL);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return self;
#line 725 "FSpotPhotoVersionsTable.c"
}


static DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* data_imports_fspot_db_fspot_photo_versions_v0_behavior_new (void) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return data_imports_fspot_db_fspot_photo_versions_v0_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR);
#line 732 "FSpotPhotoVersionsTable.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return self ? g_object_ref (self) : NULL;
#line 739 "FSpotPhotoVersionsTable.c"
}


DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* data_imports_fspot_db_fspot_photo_versions_v0_behavior_get_instance (void) {
	DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* result = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* _tmp0_;
	DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* _tmp2_;
	DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* _tmp3_;
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_versions_v0_behavior_instance;
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp0_ == NULL) {
#line 752 "FSpotPhotoVersionsTable.c"
		DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* _tmp1_;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp1_ = data_imports_fspot_db_fspot_photo_versions_v0_behavior_new ();
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (data_imports_fspot_db_fspot_photo_versions_v0_behavior_instance);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		data_imports_fspot_db_fspot_photo_versions_v0_behavior_instance = _tmp1_;
#line 760 "FSpotPhotoVersionsTable.c"
	}
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_photo_versions_v0_behavior_instance;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp3_;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 770 "FSpotPhotoVersionsTable.c"
}


static gchar* data_imports_fspot_db_fspot_photo_versions_v0_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base) {
	DataImportsFSpotDbFSpotPhotoVersionsV0Behavior * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV0Behavior);
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = g_strdup (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_TABLE_TABLE_NAME);
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp0_;
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 786 "FSpotPhotoVersionsTable.c"
}


static gchar** data_imports_fspot_db_fspot_photo_versions_v0_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1) {
	DataImportsFSpotDbFSpotPhotoVersionsV0Behavior * self;
	gchar** result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
	gchar** _tmp5_;
	gint _tmp5__length1;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV0Behavior);
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = g_strdup ("photo_id");
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_ = g_strdup ("version_id");
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = g_strdup ("name");
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = g_strdup ("uri");
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_ = g_new0 (gchar*, 4 + 1);
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_[0] = _tmp0_;
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_[1] = _tmp1_;
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_[2] = _tmp2_;
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_[3] = _tmp3_;
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_ = _tmp4_;
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5__length1 = 4;
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (result_length1) {
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		*result_length1 = _tmp5__length1;
#line 828 "FSpotPhotoVersionsTable.c"
	}
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp5_;
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 834 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v0_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoVersionRow* * row, gint offset) {
	DataImportsFSpotDbFSpotPhotoVersionsV0Behavior * self;
	DataImportsFSpotDbFSpotPhotoVersionRow* _vala_row = NULL;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp0_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp1_;
	sqlite3_stmt* _tmp2_;
	gint _tmp3_;
	gint64 _tmp4_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp5_;
	sqlite3_stmt* _tmp6_;
	gint _tmp7_;
	gint64 _tmp8_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp9_;
	sqlite3_stmt* _tmp10_;
	gint _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* full_path = NULL;
	sqlite3_stmt* _tmp14_;
	gint _tmp15_;
	const gchar* _tmp16_;
	gchar* _tmp17_;
	const gchar* _tmp18_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp27_;
	gchar* _tmp28_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp29_;
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV0Behavior);
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	g_return_if_fail (stmt != NULL);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_version_row_new ();
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_object_unref0 (_vala_row);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_vala_row = _tmp0_;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_ = _vala_row;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = stmt;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = offset;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_ = sqlite3_column_int64 (_tmp2_, _tmp3_ + 0);
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_->photo_id = _tmp4_;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_ = _vala_row;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_ = stmt;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_ = offset;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp8_ = sqlite3_column_int64 (_tmp6_, _tmp7_ + 1);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_->version_id = _tmp8_;
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp9_ = _vala_row;
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp10_ = stmt;
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp11_ = offset;
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp12_ = sqlite3_column_text (_tmp10_, _tmp11_ + 2);
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp13_ = g_strdup (_tmp12_);
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (_tmp9_->name);
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp9_->name = _tmp13_;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp14_ = stmt;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp15_ = offset;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp16_ = sqlite3_column_text (_tmp14_, _tmp15_ + 3);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp17_ = g_strdup (_tmp16_);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	full_path = _tmp17_;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp18_ = full_path;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp18_ != NULL) {
#line 922 "FSpotPhotoVersionsTable.c"
		GFile* uri = NULL;
		const gchar* _tmp19_;
		GFile* _tmp20_;
		DataImportsFSpotDbFSpotPhotoVersionRow* _tmp21_;
		GFile* _tmp22_;
		GFile* _tmp23_;
		DataImportsFSpotDbFSpotPhotoVersionRow* _tmp24_;
		GFile* _tmp25_;
		gchar* _tmp26_;
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp19_ = full_path;
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp20_ = g_file_new_for_uri (_tmp19_);
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		uri = _tmp20_;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp21_ = _vala_row;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp22_ = uri;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp23_ = g_file_get_parent (_tmp22_);
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (_tmp21_->base_path);
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp21_->base_path = _tmp23_;
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp24_ = _vala_row;
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp25_ = uri;
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp26_ = g_file_get_basename (_tmp25_);
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_free0 (_tmp24_->filename);
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp24_->filename = _tmp26_;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (uri);
#line 960 "FSpotPhotoVersionsTable.c"
	}
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp27_ = _vala_row;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp28_ = g_strdup ("");
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (_tmp27_->md5_sum);
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp27_->md5_sum = _tmp28_;
#line 101 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp29_ = _vala_row;
#line 101 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp29_->is_protected = FALSE;
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (full_path);
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (row) {
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		*row = _vala_row;
#line 980 "FSpotPhotoVersionsTable.c"
	} else {
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (_vala_row);
#line 984 "FSpotPhotoVersionsTable.c"
	}
}


static void data_imports_fspot_db_fspot_photo_versions_v0_behavior_class_init (DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorClass * klass) {
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	data_imports_fspot_db_fspot_photo_versions_v0_behavior_parent_class = g_type_class_peek_parent (klass);
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photo_versions_v0_behavior_finalize;
#line 994 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v0_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init (DataImportsFSpotDbFSpotTableBehaviorIface * iface) {
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	data_imports_fspot_db_fspot_photo_versions_v0_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = g_type_interface_peek_parent (iface);
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->get_table_name = (gchar* (*) (DataImportsFSpotDbFSpotTableBehavior *)) data_imports_fspot_db_fspot_photo_versions_v0_behavior_real_get_table_name;
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->list_columns = (gchar** (*) (DataImportsFSpotDbFSpotTableBehavior *, int*)) data_imports_fspot_db_fspot_photo_versions_v0_behavior_real_list_columns;
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->build_row = (void (*) (DataImportsFSpotDbFSpotTableBehavior *, sqlite3_stmt*, gpointer*, gint)) data_imports_fspot_db_fspot_photo_versions_v0_behavior_real_build_row;
#line 1007 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v0_behavior_instance_init (DataImportsFSpotDbFSpotPhotoVersionsV0Behavior * self) {
}


static void data_imports_fspot_db_fspot_photo_versions_v0_behavior_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotoVersionsV0Behavior * self;
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV0Behavior);
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photo_versions_v0_behavior_parent_class)->finalize (obj);
#line 1021 "FSpotPhotoVersionsTable.c"
}


GType data_imports_fspot_db_fspot_photo_versions_v0_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photo_versions_v0_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photo_versions_v0_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photo_versions_v0_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotoVersionsV0Behavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photo_versions_v0_behavior_instance_init, NULL };
		static const GInterfaceInfo data_imports_fspot_db_fspot_table_behavior_info = { (GInterfaceInitFunc) data_imports_fspot_db_fspot_photo_versions_v0_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_fspot_db_fspot_photo_versions_v0_behavior_type_id;
		data_imports_fspot_db_fspot_photo_versions_v0_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotoVersionsV0Behavior", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_fspot_db_fspot_photo_versions_v0_behavior_type_id, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, &data_imports_fspot_db_fspot_table_behavior_info);
		g_once_init_leave (&data_imports_fspot_db_fspot_photo_versions_v0_behavior_type_id__volatile, data_imports_fspot_db_fspot_photo_versions_v0_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_photo_versions_v0_behavior_type_id__volatile;
}


static DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* data_imports_fspot_db_fspot_photo_versions_v9_behavior_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotoVersionsV9Behavior * self = NULL;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = (DataImportsFSpotDbFSpotPhotoVersionsV9Behavior*) g_object_new (object_type, NULL);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return self;
#line 1045 "FSpotPhotoVersionsTable.c"
}


static DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* data_imports_fspot_db_fspot_photo_versions_v9_behavior_new (void) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return data_imports_fspot_db_fspot_photo_versions_v9_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR);
#line 1052 "FSpotPhotoVersionsTable.c"
}


DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* data_imports_fspot_db_fspot_photo_versions_v9_behavior_get_instance (void) {
	DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* result = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* _tmp0_;
	DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* _tmp2_;
	DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* _tmp3_;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_versions_v9_behavior_instance;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp0_ == NULL) {
#line 1065 "FSpotPhotoVersionsTable.c"
		DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* _tmp1_;
#line 115 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp1_ = data_imports_fspot_db_fspot_photo_versions_v9_behavior_new ();
#line 115 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (data_imports_fspot_db_fspot_photo_versions_v9_behavior_instance);
#line 115 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		data_imports_fspot_db_fspot_photo_versions_v9_behavior_instance = _tmp1_;
#line 1073 "FSpotPhotoVersionsTable.c"
	}
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_photo_versions_v9_behavior_instance;
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp3_;
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 1083 "FSpotPhotoVersionsTable.c"
}


static gchar* data_imports_fspot_db_fspot_photo_versions_v9_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base) {
	DataImportsFSpotDbFSpotPhotoVersionsV9Behavior * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 119 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV9Behavior);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = g_strdup (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_TABLE_TABLE_NAME);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp0_;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 1099 "FSpotPhotoVersionsTable.c"
}


static gchar** data_imports_fspot_db_fspot_photo_versions_v9_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1) {
	DataImportsFSpotDbFSpotPhotoVersionsV9Behavior * self;
	gchar** result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar** _tmp5_;
	gchar** _tmp6_;
	gint _tmp6__length1;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV9Behavior);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = g_strdup ("photo_id");
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_ = g_strdup ("version_id");
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = g_strdup ("name");
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = g_strdup ("uri");
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_ = g_strdup ("protected");
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_ = g_new0 (gchar*, 5 + 1);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_[0] = _tmp0_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_[1] = _tmp1_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_[2] = _tmp2_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_[3] = _tmp3_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_[4] = _tmp4_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_ = _tmp5_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6__length1 = 5;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (result_length1) {
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		*result_length1 = _tmp6__length1;
#line 1146 "FSpotPhotoVersionsTable.c"
	}
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp6_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 1152 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v9_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoVersionRow* * row, gint offset) {
	DataImportsFSpotDbFSpotPhotoVersionsV9Behavior * self;
	DataImportsFSpotDbFSpotPhotoVersionRow* _vala_row = NULL;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp0_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp1_;
	sqlite3_stmt* _tmp2_;
	gint _tmp3_;
	gint64 _tmp4_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp5_;
	sqlite3_stmt* _tmp6_;
	gint _tmp7_;
	gint64 _tmp8_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp9_;
	sqlite3_stmt* _tmp10_;
	gint _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* full_path = NULL;
	sqlite3_stmt* _tmp14_;
	gint _tmp15_;
	const gchar* _tmp16_;
	gchar* _tmp17_;
	const gchar* _tmp18_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp27_;
	gchar* _tmp28_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp29_;
	sqlite3_stmt* _tmp30_;
	gint _tmp31_;
	gint _tmp32_;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV9Behavior);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	g_return_if_fail (stmt != NULL);
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_version_row_new ();
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_object_unref0 (_vala_row);
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_vala_row = _tmp0_;
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_ = _vala_row;
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = stmt;
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = offset;
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_ = sqlite3_column_int64 (_tmp2_, _tmp3_ + 0);
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_->photo_id = _tmp4_;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_ = _vala_row;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_ = stmt;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_ = offset;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp8_ = sqlite3_column_int64 (_tmp6_, _tmp7_ + 1);
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_->version_id = _tmp8_;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp9_ = _vala_row;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp10_ = stmt;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp11_ = offset;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp12_ = sqlite3_column_text (_tmp10_, _tmp11_ + 2);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp13_ = g_strdup (_tmp12_);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (_tmp9_->name);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp9_->name = _tmp13_;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp14_ = stmt;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp15_ = offset;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp16_ = sqlite3_column_text (_tmp14_, _tmp15_ + 3);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp17_ = g_strdup (_tmp16_);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	full_path = _tmp17_;
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp18_ = full_path;
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp18_ != NULL) {
#line 1243 "FSpotPhotoVersionsTable.c"
		GFile* uri = NULL;
		const gchar* _tmp19_;
		GFile* _tmp20_;
		DataImportsFSpotDbFSpotPhotoVersionRow* _tmp21_;
		GFile* _tmp22_;
		GFile* _tmp23_;
		DataImportsFSpotDbFSpotPhotoVersionRow* _tmp24_;
		GFile* _tmp25_;
		gchar* _tmp26_;
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp19_ = full_path;
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp20_ = g_file_new_for_uri (_tmp19_);
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		uri = _tmp20_;
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp21_ = _vala_row;
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp22_ = uri;
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp23_ = g_file_get_parent (_tmp22_);
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (_tmp21_->base_path);
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp21_->base_path = _tmp23_;
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp24_ = _vala_row;
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp25_ = uri;
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp26_ = g_file_get_basename (_tmp25_);
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_free0 (_tmp24_->filename);
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp24_->filename = _tmp26_;
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (uri);
#line 1281 "FSpotPhotoVersionsTable.c"
	}
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp27_ = _vala_row;
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp28_ = g_strdup ("");
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (_tmp27_->md5_sum);
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp27_->md5_sum = _tmp28_;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp29_ = _vala_row;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp30_ = stmt;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp31_ = offset;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp32_ = sqlite3_column_int (_tmp30_, _tmp31_ + 4);
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp29_->is_protected = _tmp32_ > 0;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (full_path);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (row) {
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		*row = _vala_row;
#line 1307 "FSpotPhotoVersionsTable.c"
	} else {
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (_vala_row);
#line 1311 "FSpotPhotoVersionsTable.c"
	}
}


static void data_imports_fspot_db_fspot_photo_versions_v9_behavior_class_init (DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorClass * klass) {
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	data_imports_fspot_db_fspot_photo_versions_v9_behavior_parent_class = g_type_class_peek_parent (klass);
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photo_versions_v9_behavior_finalize;
#line 1321 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v9_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init (DataImportsFSpotDbFSpotTableBehaviorIface * iface) {
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	data_imports_fspot_db_fspot_photo_versions_v9_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = g_type_interface_peek_parent (iface);
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->get_table_name = (gchar* (*) (DataImportsFSpotDbFSpotTableBehavior *)) data_imports_fspot_db_fspot_photo_versions_v9_behavior_real_get_table_name;
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->list_columns = (gchar** (*) (DataImportsFSpotDbFSpotTableBehavior *, int*)) data_imports_fspot_db_fspot_photo_versions_v9_behavior_real_list_columns;
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->build_row = (void (*) (DataImportsFSpotDbFSpotTableBehavior *, sqlite3_stmt*, gpointer*, gint)) data_imports_fspot_db_fspot_photo_versions_v9_behavior_real_build_row;
#line 1334 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v9_behavior_instance_init (DataImportsFSpotDbFSpotPhotoVersionsV9Behavior * self) {
}


static void data_imports_fspot_db_fspot_photo_versions_v9_behavior_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotoVersionsV9Behavior * self;
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV9Behavior);
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photo_versions_v9_behavior_parent_class)->finalize (obj);
#line 1348 "FSpotPhotoVersionsTable.c"
}


GType data_imports_fspot_db_fspot_photo_versions_v9_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photo_versions_v9_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photo_versions_v9_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photo_versions_v9_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotoVersionsV9Behavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photo_versions_v9_behavior_instance_init, NULL };
		static const GInterfaceInfo data_imports_fspot_db_fspot_table_behavior_info = { (GInterfaceInitFunc) data_imports_fspot_db_fspot_photo_versions_v9_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_fspot_db_fspot_photo_versions_v9_behavior_type_id;
		data_imports_fspot_db_fspot_photo_versions_v9_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotoVersionsV9Behavior", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_fspot_db_fspot_photo_versions_v9_behavior_type_id, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, &data_imports_fspot_db_fspot_table_behavior_info);
		g_once_init_leave (&data_imports_fspot_db_fspot_photo_versions_v9_behavior_type_id__volatile, data_imports_fspot_db_fspot_photo_versions_v9_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_photo_versions_v9_behavior_type_id__volatile;
}


static DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* data_imports_fspot_db_fspot_photo_versions_v16_behavior_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotoVersionsV16Behavior * self = NULL;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = (DataImportsFSpotDbFSpotPhotoVersionsV16Behavior*) g_object_new (object_type, NULL);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return self;
#line 1372 "FSpotPhotoVersionsTable.c"
}


static DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* data_imports_fspot_db_fspot_photo_versions_v16_behavior_new (void) {
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return data_imports_fspot_db_fspot_photo_versions_v16_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR);
#line 1379 "FSpotPhotoVersionsTable.c"
}


DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* data_imports_fspot_db_fspot_photo_versions_v16_behavior_get_instance (void) {
	DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* result = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* _tmp0_;
	DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* _tmp2_;
	DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* _tmp3_;
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_versions_v16_behavior_instance;
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp0_ == NULL) {
#line 1392 "FSpotPhotoVersionsTable.c"
		DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* _tmp1_;
#line 156 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp1_ = data_imports_fspot_db_fspot_photo_versions_v16_behavior_new ();
#line 156 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (data_imports_fspot_db_fspot_photo_versions_v16_behavior_instance);
#line 156 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		data_imports_fspot_db_fspot_photo_versions_v16_behavior_instance = _tmp1_;
#line 1400 "FSpotPhotoVersionsTable.c"
	}
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_photo_versions_v16_behavior_instance;
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp3_;
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 1410 "FSpotPhotoVersionsTable.c"
}


static gchar* data_imports_fspot_db_fspot_photo_versions_v16_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base) {
	DataImportsFSpotDbFSpotPhotoVersionsV16Behavior * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV16Behavior);
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = g_strdup (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_TABLE_TABLE_NAME);
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp0_;
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 1426 "FSpotPhotoVersionsTable.c"
}


static gchar** data_imports_fspot_db_fspot_photo_versions_v16_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1) {
	DataImportsFSpotDbFSpotPhotoVersionsV16Behavior * self;
	gchar** result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar** _tmp6_;
	gchar** _tmp7_;
	gint _tmp7__length1;
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV16Behavior);
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = g_strdup ("photo_id");
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_ = g_strdup ("version_id");
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = g_strdup ("name");
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = g_strdup ("uri");
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_ = g_strdup ("md5_sum");
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_ = g_strdup ("protected");
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_ = g_new0 (gchar*, 6 + 1);
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_[0] = _tmp0_;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_[1] = _tmp1_;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_[2] = _tmp2_;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_[3] = _tmp3_;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_[4] = _tmp4_;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_[5] = _tmp5_;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_ = _tmp6_;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7__length1 = 6;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (result_length1) {
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		*result_length1 = _tmp7__length1;
#line 1478 "FSpotPhotoVersionsTable.c"
	}
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp7_;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 1484 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v16_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoVersionRow* * row, gint offset) {
	DataImportsFSpotDbFSpotPhotoVersionsV16Behavior * self;
	DataImportsFSpotDbFSpotPhotoVersionRow* _vala_row = NULL;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp0_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp1_;
	sqlite3_stmt* _tmp2_;
	gint _tmp3_;
	gint64 _tmp4_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp5_;
	sqlite3_stmt* _tmp6_;
	gint _tmp7_;
	gint64 _tmp8_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp9_;
	sqlite3_stmt* _tmp10_;
	gint _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* full_path = NULL;
	sqlite3_stmt* _tmp14_;
	gint _tmp15_;
	const gchar* _tmp16_;
	gchar* _tmp17_;
	const gchar* _tmp18_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp27_;
	sqlite3_stmt* _tmp28_;
	gint _tmp29_;
	const gchar* _tmp30_;
	gchar* _tmp31_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp32_;
	sqlite3_stmt* _tmp33_;
	gint _tmp34_;
	gint _tmp35_;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV16Behavior);
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	g_return_if_fail (stmt != NULL);
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_version_row_new ();
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_object_unref0 (_vala_row);
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_vala_row = _tmp0_;
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_ = _vala_row;
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = stmt;
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = offset;
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_ = sqlite3_column_int64 (_tmp2_, _tmp3_ + 0);
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_->photo_id = _tmp4_;
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_ = _vala_row;
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_ = stmt;
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_ = offset;
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp8_ = sqlite3_column_int64 (_tmp6_, _tmp7_ + 1);
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_->version_id = _tmp8_;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp9_ = _vala_row;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp10_ = stmt;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp11_ = offset;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp12_ = sqlite3_column_text (_tmp10_, _tmp11_ + 2);
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp13_ = g_strdup (_tmp12_);
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (_tmp9_->name);
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp9_->name = _tmp13_;
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp14_ = stmt;
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp15_ = offset;
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp16_ = sqlite3_column_text (_tmp14_, _tmp15_ + 3);
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp17_ = g_strdup (_tmp16_);
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	full_path = _tmp17_;
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp18_ = full_path;
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp18_ != NULL) {
#line 1578 "FSpotPhotoVersionsTable.c"
		GFile* uri = NULL;
		const gchar* _tmp19_;
		GFile* _tmp20_;
		DataImportsFSpotDbFSpotPhotoVersionRow* _tmp21_;
		GFile* _tmp22_;
		GFile* _tmp23_;
		DataImportsFSpotDbFSpotPhotoVersionRow* _tmp24_;
		GFile* _tmp25_;
		gchar* _tmp26_;
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp19_ = full_path;
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp20_ = g_file_new_for_uri (_tmp19_);
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		uri = _tmp20_;
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp21_ = _vala_row;
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp22_ = uri;
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp23_ = g_file_get_parent (_tmp22_);
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (_tmp21_->base_path);
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp21_->base_path = _tmp23_;
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp24_ = _vala_row;
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp25_ = uri;
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp26_ = g_file_get_basename (_tmp25_);
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_free0 (_tmp24_->filename);
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp24_->filename = _tmp26_;
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (uri);
#line 1616 "FSpotPhotoVersionsTable.c"
	}
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp27_ = _vala_row;
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp28_ = stmt;
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp29_ = offset;
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp30_ = sqlite3_column_text (_tmp28_, _tmp29_ + 4);
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp31_ = g_strdup (_tmp30_);
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (_tmp27_->md5_sum);
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp27_->md5_sum = _tmp31_;
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp32_ = _vala_row;
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp33_ = stmt;
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp34_ = offset;
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp35_ = sqlite3_column_int (_tmp33_, _tmp34_ + 5);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp32_->is_protected = _tmp35_ > 0;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (full_path);
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (row) {
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		*row = _vala_row;
#line 1648 "FSpotPhotoVersionsTable.c"
	} else {
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (_vala_row);
#line 1652 "FSpotPhotoVersionsTable.c"
	}
}


static void data_imports_fspot_db_fspot_photo_versions_v16_behavior_class_init (DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorClass * klass) {
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	data_imports_fspot_db_fspot_photo_versions_v16_behavior_parent_class = g_type_class_peek_parent (klass);
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photo_versions_v16_behavior_finalize;
#line 1662 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v16_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init (DataImportsFSpotDbFSpotTableBehaviorIface * iface) {
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	data_imports_fspot_db_fspot_photo_versions_v16_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = g_type_interface_peek_parent (iface);
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->get_table_name = (gchar* (*) (DataImportsFSpotDbFSpotTableBehavior *)) data_imports_fspot_db_fspot_photo_versions_v16_behavior_real_get_table_name;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->list_columns = (gchar** (*) (DataImportsFSpotDbFSpotTableBehavior *, int*)) data_imports_fspot_db_fspot_photo_versions_v16_behavior_real_list_columns;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->build_row = (void (*) (DataImportsFSpotDbFSpotTableBehavior *, sqlite3_stmt*, gpointer*, gint)) data_imports_fspot_db_fspot_photo_versions_v16_behavior_real_build_row;
#line 1675 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v16_behavior_instance_init (DataImportsFSpotDbFSpotPhotoVersionsV16Behavior * self) {
}


static void data_imports_fspot_db_fspot_photo_versions_v16_behavior_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotoVersionsV16Behavior * self;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV16Behavior);
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photo_versions_v16_behavior_parent_class)->finalize (obj);
#line 1689 "FSpotPhotoVersionsTable.c"
}


GType data_imports_fspot_db_fspot_photo_versions_v16_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photo_versions_v16_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photo_versions_v16_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photo_versions_v16_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotoVersionsV16Behavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photo_versions_v16_behavior_instance_init, NULL };
		static const GInterfaceInfo data_imports_fspot_db_fspot_table_behavior_info = { (GInterfaceInitFunc) data_imports_fspot_db_fspot_photo_versions_v16_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_fspot_db_fspot_photo_versions_v16_behavior_type_id;
		data_imports_fspot_db_fspot_photo_versions_v16_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotoVersionsV16Behavior", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_fspot_db_fspot_photo_versions_v16_behavior_type_id, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, &data_imports_fspot_db_fspot_table_behavior_info);
		g_once_init_leave (&data_imports_fspot_db_fspot_photo_versions_v16_behavior_type_id__volatile, data_imports_fspot_db_fspot_photo_versions_v16_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_photo_versions_v16_behavior_type_id__volatile;
}


static DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* data_imports_fspot_db_fspot_photo_versions_v17_behavior_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotoVersionsV17Behavior * self = NULL;
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = (DataImportsFSpotDbFSpotPhotoVersionsV17Behavior*) g_object_new (object_type, NULL);
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return self;
#line 1713 "FSpotPhotoVersionsTable.c"
}


static DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* data_imports_fspot_db_fspot_photo_versions_v17_behavior_new (void) {
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return data_imports_fspot_db_fspot_photo_versions_v17_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR);
#line 1720 "FSpotPhotoVersionsTable.c"
}


DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* data_imports_fspot_db_fspot_photo_versions_v17_behavior_get_instance (void) {
	DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* result = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* _tmp0_;
	DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* _tmp2_;
	DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* _tmp3_;
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_versions_v17_behavior_instance;
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp0_ == NULL) {
#line 1733 "FSpotPhotoVersionsTable.c"
		DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* _tmp1_;
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp1_ = data_imports_fspot_db_fspot_photo_versions_v17_behavior_new ();
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (data_imports_fspot_db_fspot_photo_versions_v17_behavior_instance);
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		data_imports_fspot_db_fspot_photo_versions_v17_behavior_instance = _tmp1_;
#line 1741 "FSpotPhotoVersionsTable.c"
	}
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_photo_versions_v17_behavior_instance;
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp3_;
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 1751 "FSpotPhotoVersionsTable.c"
}


static gchar* data_imports_fspot_db_fspot_photo_versions_v17_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base) {
	DataImportsFSpotDbFSpotPhotoVersionsV17Behavior * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV17Behavior);
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = g_strdup (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_TABLE_TABLE_NAME);
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp0_;
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 1767 "FSpotPhotoVersionsTable.c"
}


static gchar** data_imports_fspot_db_fspot_photo_versions_v17_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1) {
	DataImportsFSpotDbFSpotPhotoVersionsV17Behavior * self;
	gchar** result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar** _tmp7_;
	gchar** _tmp8_;
	gint _tmp8__length1;
#line 206 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV17Behavior);
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = g_strdup ("photo_id");
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_ = g_strdup ("version_id");
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = g_strdup ("name");
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = g_strdup ("base_uri");
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_ = g_strdup ("filename");
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_ = g_strdup ("md5_sum");
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_ = g_strdup ("protected");
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_ = g_new0 (gchar*, 7 + 1);
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[0] = _tmp0_;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[1] = _tmp1_;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[2] = _tmp2_;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[3] = _tmp3_;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[4] = _tmp4_;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[5] = _tmp5_;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[6] = _tmp6_;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp8_ = _tmp7_;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp8__length1 = 7;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (result_length1) {
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		*result_length1 = _tmp8__length1;
#line 1824 "FSpotPhotoVersionsTable.c"
	}
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp8_;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 1830 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v17_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoVersionRow* * row, gint offset) {
	DataImportsFSpotDbFSpotPhotoVersionsV17Behavior * self;
	DataImportsFSpotDbFSpotPhotoVersionRow* _vala_row = NULL;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp0_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp1_;
	sqlite3_stmt* _tmp2_;
	gint _tmp3_;
	gint64 _tmp4_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp5_;
	sqlite3_stmt* _tmp6_;
	gint _tmp7_;
	gint64 _tmp8_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp9_;
	sqlite3_stmt* _tmp10_;
	gint _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* base_path = NULL;
	sqlite3_stmt* _tmp14_;
	gint _tmp15_;
	const gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* filename = NULL;
	sqlite3_stmt* _tmp18_;
	gint _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	gboolean _tmp22_ = FALSE;
	const gchar* _tmp23_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp31_;
	sqlite3_stmt* _tmp32_;
	gint _tmp33_;
	const gchar* _tmp34_;
	gchar* _tmp35_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp36_;
	sqlite3_stmt* _tmp37_;
	gint _tmp38_;
	gint _tmp39_;
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV17Behavior);
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	g_return_if_fail (stmt != NULL);
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_version_row_new ();
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_object_unref0 (_vala_row);
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_vala_row = _tmp0_;
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_ = _vala_row;
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = stmt;
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = offset;
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_ = sqlite3_column_int64 (_tmp2_, _tmp3_ + 0);
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_->photo_id = _tmp4_;
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_ = _vala_row;
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_ = stmt;
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_ = offset;
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp8_ = sqlite3_column_int64 (_tmp6_, _tmp7_ + 1);
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_->version_id = _tmp8_;
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp9_ = _vala_row;
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp10_ = stmt;
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp11_ = offset;
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp12_ = sqlite3_column_text (_tmp10_, _tmp11_ + 2);
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp13_ = g_strdup (_tmp12_);
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (_tmp9_->name);
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp9_->name = _tmp13_;
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp14_ = stmt;
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp15_ = offset;
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp16_ = sqlite3_column_text (_tmp14_, _tmp15_ + 3);
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp17_ = g_strdup (_tmp16_);
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	base_path = _tmp17_;
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp18_ = stmt;
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp19_ = offset;
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp20_ = sqlite3_column_text (_tmp18_, _tmp19_ + 4);
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp21_ = g_strdup (_tmp20_);
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	filename = _tmp21_;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp23_ = base_path;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp23_ != NULL) {
#line 1940 "FSpotPhotoVersionsTable.c"
		const gchar* _tmp24_;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp24_ = filename;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp22_ = _tmp24_ != NULL;
#line 1946 "FSpotPhotoVersionsTable.c"
	} else {
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp22_ = FALSE;
#line 1950 "FSpotPhotoVersionsTable.c"
	}
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp22_) {
#line 1954 "FSpotPhotoVersionsTable.c"
		DataImportsFSpotDbFSpotPhotoVersionRow* _tmp25_;
		const gchar* _tmp26_;
		GFile* _tmp27_;
		DataImportsFSpotDbFSpotPhotoVersionRow* _tmp28_;
		const gchar* _tmp29_;
		gchar* _tmp30_;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp25_ = _vala_row;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp26_ = base_path;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp27_ = g_file_new_for_uri (_tmp26_);
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (_tmp25_->base_path);
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp25_->base_path = _tmp27_;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp28_ = _vala_row;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp29_ = filename;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp30_ = g_strdup (_tmp29_);
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_free0 (_tmp28_->filename);
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp28_->filename = _tmp30_;
#line 1981 "FSpotPhotoVersionsTable.c"
	}
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp31_ = _vala_row;
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp32_ = stmt;
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp33_ = offset;
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp34_ = sqlite3_column_text (_tmp32_, _tmp33_ + 5);
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp35_ = g_strdup (_tmp34_);
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (_tmp31_->md5_sum);
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp31_->md5_sum = _tmp35_;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp36_ = _vala_row;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp37_ = stmt;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp38_ = offset;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp39_ = sqlite3_column_int (_tmp37_, _tmp38_ + 6);
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp36_->is_protected = _tmp39_ > 0;
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (filename);
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (base_path);
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (row) {
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		*row = _vala_row;
#line 2015 "FSpotPhotoVersionsTable.c"
	} else {
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (_vala_row);
#line 2019 "FSpotPhotoVersionsTable.c"
	}
}


static void data_imports_fspot_db_fspot_photo_versions_v17_behavior_class_init (DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorClass * klass) {
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	data_imports_fspot_db_fspot_photo_versions_v17_behavior_parent_class = g_type_class_peek_parent (klass);
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photo_versions_v17_behavior_finalize;
#line 2029 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v17_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init (DataImportsFSpotDbFSpotTableBehaviorIface * iface) {
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	data_imports_fspot_db_fspot_photo_versions_v17_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = g_type_interface_peek_parent (iface);
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->get_table_name = (gchar* (*) (DataImportsFSpotDbFSpotTableBehavior *)) data_imports_fspot_db_fspot_photo_versions_v17_behavior_real_get_table_name;
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->list_columns = (gchar** (*) (DataImportsFSpotDbFSpotTableBehavior *, int*)) data_imports_fspot_db_fspot_photo_versions_v17_behavior_real_list_columns;
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->build_row = (void (*) (DataImportsFSpotDbFSpotTableBehavior *, sqlite3_stmt*, gpointer*, gint)) data_imports_fspot_db_fspot_photo_versions_v17_behavior_real_build_row;
#line 2042 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v17_behavior_instance_init (DataImportsFSpotDbFSpotPhotoVersionsV17Behavior * self) {
}


static void data_imports_fspot_db_fspot_photo_versions_v17_behavior_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotoVersionsV17Behavior * self;
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV17Behavior);
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photo_versions_v17_behavior_parent_class)->finalize (obj);
#line 2056 "FSpotPhotoVersionsTable.c"
}


GType data_imports_fspot_db_fspot_photo_versions_v17_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photo_versions_v17_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photo_versions_v17_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photo_versions_v17_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotoVersionsV17Behavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photo_versions_v17_behavior_instance_init, NULL };
		static const GInterfaceInfo data_imports_fspot_db_fspot_table_behavior_info = { (GInterfaceInitFunc) data_imports_fspot_db_fspot_photo_versions_v17_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_fspot_db_fspot_photo_versions_v17_behavior_type_id;
		data_imports_fspot_db_fspot_photo_versions_v17_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotoVersionsV17Behavior", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_fspot_db_fspot_photo_versions_v17_behavior_type_id, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, &data_imports_fspot_db_fspot_table_behavior_info);
		g_once_init_leave (&data_imports_fspot_db_fspot_photo_versions_v17_behavior_type_id__volatile, data_imports_fspot_db_fspot_photo_versions_v17_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_photo_versions_v17_behavior_type_id__volatile;
}


static DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* data_imports_fspot_db_fspot_photo_versions_v18_behavior_construct (GType object_type) {
	DataImportsFSpotDbFSpotPhotoVersionsV18Behavior * self = NULL;
#line 234 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = (DataImportsFSpotDbFSpotPhotoVersionsV18Behavior*) g_object_new (object_type, NULL);
#line 234 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return self;
#line 2080 "FSpotPhotoVersionsTable.c"
}


static DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* data_imports_fspot_db_fspot_photo_versions_v18_behavior_new (void) {
#line 234 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return data_imports_fspot_db_fspot_photo_versions_v18_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR);
#line 2087 "FSpotPhotoVersionsTable.c"
}


DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* data_imports_fspot_db_fspot_photo_versions_v18_behavior_get_instance (void) {
	DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* result = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* _tmp0_;
	DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* _tmp2_;
	DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* _tmp3_;
#line 238 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_versions_v18_behavior_instance;
#line 238 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp0_ == NULL) {
#line 2100 "FSpotPhotoVersionsTable.c"
		DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* _tmp1_;
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp1_ = data_imports_fspot_db_fspot_photo_versions_v18_behavior_new ();
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (data_imports_fspot_db_fspot_photo_versions_v18_behavior_instance);
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		data_imports_fspot_db_fspot_photo_versions_v18_behavior_instance = _tmp1_;
#line 2108 "FSpotPhotoVersionsTable.c"
	}
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_photo_versions_v18_behavior_instance;
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp3_;
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 2118 "FSpotPhotoVersionsTable.c"
}


static gchar* data_imports_fspot_db_fspot_photo_versions_v18_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base) {
	DataImportsFSpotDbFSpotPhotoVersionsV18Behavior * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 243 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV18Behavior);
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = g_strdup (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_TABLE_TABLE_NAME);
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp0_;
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 2134 "FSpotPhotoVersionsTable.c"
}


static gchar** data_imports_fspot_db_fspot_photo_versions_v18_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1) {
	DataImportsFSpotDbFSpotPhotoVersionsV18Behavior * self;
	gchar** result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar** _tmp7_;
	gchar** _tmp8_;
	gint _tmp8__length1;
#line 247 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV18Behavior);
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = g_strdup ("photo_id");
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_ = g_strdup ("version_id");
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = g_strdup ("name");
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = g_strdup ("base_uri");
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_ = g_strdup ("filename");
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_ = g_strdup ("import_md5");
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_ = g_strdup ("protected");
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_ = g_new0 (gchar*, 7 + 1);
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[0] = _tmp0_;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[1] = _tmp1_;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[2] = _tmp2_;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[3] = _tmp3_;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[4] = _tmp4_;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[5] = _tmp5_;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_[6] = _tmp6_;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp8_ = _tmp7_;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp8__length1 = 7;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (result_length1) {
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		*result_length1 = _tmp8__length1;
#line 2191 "FSpotPhotoVersionsTable.c"
	}
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	result = _tmp8_;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	return result;
#line 2197 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v18_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotPhotoVersionRow* * row, gint offset) {
	DataImportsFSpotDbFSpotPhotoVersionsV18Behavior * self;
	DataImportsFSpotDbFSpotPhotoVersionRow* _vala_row = NULL;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp0_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp1_;
	sqlite3_stmt* _tmp2_;
	gint _tmp3_;
	gint64 _tmp4_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp5_;
	sqlite3_stmt* _tmp6_;
	gint _tmp7_;
	gint64 _tmp8_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp9_;
	sqlite3_stmt* _tmp10_;
	gint _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* base_path = NULL;
	sqlite3_stmt* _tmp14_;
	gint _tmp15_;
	const gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* filename = NULL;
	sqlite3_stmt* _tmp18_;
	gint _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	gboolean _tmp22_ = FALSE;
	const gchar* _tmp23_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp31_;
	sqlite3_stmt* _tmp32_;
	gint _tmp33_;
	const gchar* _tmp34_;
	gchar* _tmp35_;
	DataImportsFSpotDbFSpotPhotoVersionRow* _tmp36_;
	sqlite3_stmt* _tmp37_;
	gint _tmp38_;
	gint _tmp39_;
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV18Behavior);
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	g_return_if_fail (stmt != NULL);
#line 253 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_photo_version_row_new ();
#line 253 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_object_unref0 (_vala_row);
#line 253 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_vala_row = _tmp0_;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_ = _vala_row;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp2_ = stmt;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp3_ = offset;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp4_ = sqlite3_column_int64 (_tmp2_, _tmp3_ + 0);
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp1_->photo_id = _tmp4_;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_ = _vala_row;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp6_ = stmt;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp7_ = offset;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp8_ = sqlite3_column_int64 (_tmp6_, _tmp7_ + 1);
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp5_->version_id = _tmp8_;
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp9_ = _vala_row;
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp10_ = stmt;
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp11_ = offset;
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp12_ = sqlite3_column_text (_tmp10_, _tmp11_ + 2);
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp13_ = g_strdup (_tmp12_);
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (_tmp9_->name);
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp9_->name = _tmp13_;
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp14_ = stmt;
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp15_ = offset;
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp16_ = sqlite3_column_text (_tmp14_, _tmp15_ + 3);
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp17_ = g_strdup (_tmp16_);
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	base_path = _tmp17_;
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp18_ = stmt;
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp19_ = offset;
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp20_ = sqlite3_column_text (_tmp18_, _tmp19_ + 4);
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp21_ = g_strdup (_tmp20_);
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	filename = _tmp21_;
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp23_ = base_path;
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp23_ != NULL) {
#line 2307 "FSpotPhotoVersionsTable.c"
		const gchar* _tmp24_;
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp24_ = filename;
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp22_ = _tmp24_ != NULL;
#line 2313 "FSpotPhotoVersionsTable.c"
	} else {
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp22_ = FALSE;
#line 2317 "FSpotPhotoVersionsTable.c"
	}
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (_tmp22_) {
#line 2321 "FSpotPhotoVersionsTable.c"
		DataImportsFSpotDbFSpotPhotoVersionRow* _tmp25_;
		const gchar* _tmp26_;
		GFile* _tmp27_;
		DataImportsFSpotDbFSpotPhotoVersionRow* _tmp28_;
		const gchar* _tmp29_;
		gchar* _tmp30_;
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp25_ = _vala_row;
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp26_ = base_path;
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp27_ = g_file_new_for_uri (_tmp26_);
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (_tmp25_->base_path);
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp25_->base_path = _tmp27_;
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp28_ = _vala_row;
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp29_ = filename;
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp30_ = g_strdup (_tmp29_);
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_free0 (_tmp28_->filename);
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_tmp28_->filename = _tmp30_;
#line 2348 "FSpotPhotoVersionsTable.c"
	}
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp31_ = _vala_row;
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp32_ = stmt;
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp33_ = offset;
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp34_ = sqlite3_column_text (_tmp32_, _tmp33_ + 5);
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp35_ = g_strdup (_tmp34_);
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (_tmp31_->md5_sum);
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp31_->md5_sum = _tmp35_;
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp36_ = _vala_row;
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp37_ = stmt;
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp38_ = offset;
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp39_ = sqlite3_column_int (_tmp37_, _tmp38_ + 6);
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_tmp36_->is_protected = _tmp39_ > 0;
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (filename);
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	_g_free0 (base_path);
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	if (row) {
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		*row = _vala_row;
#line 2382 "FSpotPhotoVersionsTable.c"
	} else {
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
		_g_object_unref0 (_vala_row);
#line 2386 "FSpotPhotoVersionsTable.c"
	}
}


static void data_imports_fspot_db_fspot_photo_versions_v18_behavior_class_init (DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorClass * klass) {
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	data_imports_fspot_db_fspot_photo_versions_v18_behavior_parent_class = g_type_class_peek_parent (klass);
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_photo_versions_v18_behavior_finalize;
#line 2396 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v18_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init (DataImportsFSpotDbFSpotTableBehaviorIface * iface) {
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	data_imports_fspot_db_fspot_photo_versions_v18_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = g_type_interface_peek_parent (iface);
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->get_table_name = (gchar* (*) (DataImportsFSpotDbFSpotTableBehavior *)) data_imports_fspot_db_fspot_photo_versions_v18_behavior_real_get_table_name;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->list_columns = (gchar** (*) (DataImportsFSpotDbFSpotTableBehavior *, int*)) data_imports_fspot_db_fspot_photo_versions_v18_behavior_real_list_columns;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	iface->build_row = (void (*) (DataImportsFSpotDbFSpotTableBehavior *, sqlite3_stmt*, gpointer*, gint)) data_imports_fspot_db_fspot_photo_versions_v18_behavior_real_build_row;
#line 2409 "FSpotPhotoVersionsTable.c"
}


static void data_imports_fspot_db_fspot_photo_versions_v18_behavior_instance_init (DataImportsFSpotDbFSpotPhotoVersionsV18Behavior * self) {
}


static void data_imports_fspot_db_fspot_photo_versions_v18_behavior_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotPhotoVersionsV18Behavior * self;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV18Behavior);
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotPhotoVersionsTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_photo_versions_v18_behavior_parent_class)->finalize (obj);
#line 2423 "FSpotPhotoVersionsTable.c"
}


GType data_imports_fspot_db_fspot_photo_versions_v18_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_photo_versions_v18_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_photo_versions_v18_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_photo_versions_v18_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotPhotoVersionsV18Behavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_photo_versions_v18_behavior_instance_init, NULL };
		static const GInterfaceInfo data_imports_fspot_db_fspot_table_behavior_info = { (GInterfaceInitFunc) data_imports_fspot_db_fspot_photo_versions_v18_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_fspot_db_fspot_photo_versions_v18_behavior_type_id;
		data_imports_fspot_db_fspot_photo_versions_v18_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotPhotoVersionsV18Behavior", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_fspot_db_fspot_photo_versions_v18_behavior_type_id, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, &data_imports_fspot_db_fspot_table_behavior_info);
		g_once_init_leave (&data_imports_fspot_db_fspot_photo_versions_v18_behavior_type_id__volatile, data_imports_fspot_db_fspot_photo_versions_v18_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_photo_versions_v18_behavior_type_id__volatile;
}



